Hello, @thomas-knoefel and All,
Indeed, changing the line :
LoadThreads="auto"
into this one :
LoadThreads=0
within the MultiReplace.ini file, the same list of files were found in 2 m ( instead of 1 m 13 s )
Thus, I decided of an experiment, changing, on purpose, the LoadThreads line to :
LoadThreads=8
After restarting my computer and doing the test, the execution time was, this time, 1 m 28 s. However, verifying within the MultiReplace.ini file, I saw the line :
LoadThreads="0"
Is this the expected behavior, with the number 0 as a string ?
Best Regards,
guy038